@@ -1,33 +1,9 @@
-    Mac OS X            	   2  *P     *                                      ATTR      *  L  )6                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      	     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Gjuliac-buildscript A427R7F42H !R3~v1                                        ~ BQoPG}G>                    XcCp0@Js5INqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac-buildscript                    
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-buildscript A427R7F42H ~ BQoPG}G>                    XcCp0@Js5IN                            juliac-buildscript                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4                      Gjuliac-buildscript A427R7F42H ONvHl_Zt+5b4UEhY2                                                                +R( 7#u9JPi                                B'G\,vke1wŬ6haq
+A427R7F42H                4                      Gjuliac-buildscript A427R7F42H +R( 7#u9JPi                                B'G\,vke1wŬ6haq
 by-\J0	*H
 010
 	`He 0	*H
@@ -106,47 +82,55 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251007183158Z0/	*H
-	1" ݷ)ΰ~:yXԢK.x<60[	*Hcd	1N0+S=SM_Nl0-	`He 9+A;)o/Ge)sqAQ0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251017142243Z0/	*H
+	1" ){AL
+/x39?Æp0[	*Hcd	1N0+2?S#?
+v0-	`He  [zy9P:w
+-ZpU40[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		Uz1TlQKpw/3HTbML2RjuG19ObOU=
+		lhrS5wwyP7FTIx7BPxjf5w33GHY=
 		</data>
 		<data>
-		Gzmx4K/E9SsSQfbAOylvL0dlKXM=
+		nSDeDFt6eec5mgHYUBoHp4866Xc=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  LDX`ؕ2lIn˻](CpZק,3	Ezgׁy؀"GYy3[lvN,K{sNolIGj4]猸kJh7-i<yذcRE?4u'(>*7Q .oocd3hudވS[ G\8sa1ˑqRtpJvC6/ݕSVa~0*H
+  D*6Kˎy*J)(Eh /񲕢/FSHlO̜" 6Ã+Հbp$hG4
+
+o-5yjis3')Y8ȤT] i+A9\y]pbuvځT'OU3J/q-&Z|-t׿=lB lMJo5Tjz{EQV[`˶öP]z8B;0 $}.C`^10R20*H
 	10	*H
 010	+ 0{*H
 	lj0h*010
-	`He  y>dHaf'Ɲ-_\fa20251007183159Z0	 4
-001|0
+	`He  CI	uN^":5NV/톗 hH>W)G20251017142244Z0	 {Dꟛ
+00oz0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-250915173520Z
-251027173519Z0A10UTimestamp Signer MA210U
+251013173520Z
+251124173519Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- HLèX%&IEF~PVjۢ1-EU@M@KnQ_pUƂo ȺHm-ݭq	O*bumBq~NvV- U:k)YlR6p
-gukhʯ)v{eSicN4ζ>]a^Gi}
-$%?V̊ȯgme}RkaPb[ 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0URphe_G:ذ0U0
+ Alv
+]kZF) $
+	vy5*CQNsS;!!f5RUB*,7+BﴚdW;
+6Ƕڀ7dɉx&q{
+aws/(DI-G9@87lgHD"!ͽO#A˳p?U1+.ɶޒM4gm
+nr#P(@Lu 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U|"Pߢ_\Vd0U0
 	*H
-  LeGژ0D?-ἁv?̓4v/&\sID3YnS3;meN#W[Ȫ\
- %3~2xЧT?J/.vS%B}az8 X0.hgͲOeFX򼛂&NAA4IVr!"8?qMl/fk)i_(RbSdu1݇x^s['q6?W>TUL՘~ȼ'00}LWc0
+  #h,&[a'E'Rb4"IPrmoW5ROt(Yr?qKkz%cH[E$mQTgM%fi:c*ũ)!@涪
+R@[YQu:w߲TL>H愀)WrHX76RV[8lmzDɒwN~~֭2twātӀ&N}VV~D00}LWc0
 	*H
  0b10	UUS10U
 
@@ -187,14 +171,17 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS1|0	+ 0	*H
+Apple Inc.10	UUSoz0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251007183159Z0#	*H
-	1,6T66y9y0+*H
-	1000j?40z|[&`i0
+251017142244Z0#	*H
+	1i%_7vJwB]0+*H
+	1000-(tWY#ţg	7M0
 	*H
-  
-U@<SQ/#@1ˮGZN,8[ǕK6YcխhX7%0𖑏<rנ)^+yB}aZl{ş₉S̠,Ͻ҈oԄ[0~Ӑ(T^4NO+0Sn<9^~EdkPWLA|iguQC::;͵;Xob?}+X3zI/ڇ;Z^z	̈      
\ No newline at end of file
+  	'[ %۔S3$13S}: ]8!Do,azsL#fTTg}޿PUаrXIzC_Z.
+XFᕑ]u#,]1S4W0B
+pU#<k*g<ug~5`:H ]gS
+\cK҃qs*iR#N0yx=eF
+vXW elNoe<ĐIY|q      
\ No newline at end of file
