@@ -1,35 +1,11 @@
-    Mac OS X            	   2  *H     *z                                      ATTR      *z  L  ).                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        o             Ejuliac-trim-base A427R7F42H !R3~v1                                        3@'\\;̗                    OMBSHqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac-trim-base                  
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      \      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              x   4        ,             Ejuliac-trim-base A427R7F42H 3@'\\;̗                    Hzo ضrCI                            juliac-trim-base                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4        o              Ejuliac-trim-base A427R7F42H ONvHl_Zt+5b4UEhY2                                                                Ƶ
+A427R7F42H                4        ,              Ejuliac-trim-base A427R7F42H Ƶ
 :aI=mކ3 Ug]
-/                                4BдJ&%@-QR	Y%~0	*H
+/                                77+9n)]i'PYZ]0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -107,50 +83,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251007183158Z0/	*H
-	1" pدn*m7?hCSZ0[	*Hcd	1N0+gp
-2ɏT%\_0-	`He ojp[/2"tZ!i0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251017142243Z0/	*H
+	1" N`̚Vhq&&Bz?}
+0[	*Hcd	1N0+/ ,UH[]롱0-	`He S)LgZ??j׳A7?i0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		ZxIc6BKqcJi41w0yyY9UFg4lXF8=
+		oy8gqyxVC5bqi/tIW3+DXeuhsfs=
 		</data>
 		<data>
-		h8pv0dJqnvTq/RhwoelbAo8vGag=
+		Uym8tkxnvFqYFD/azD+5atezQbA=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  ^1V"TPO ɎCrQ6Z~uIǒ7-BN̴;quvvsWԴk]4ـzUqgHOF˹pDhHzb2:OPƴME>b">+`;)2tP6rud޷+(zMbn'L#LuQzV/d#8nA
-JC?{Jr`6Em[(W~%) _0*H
+  G
+z+soM0/ƒQ6*^5Q)˰bCEI=٘ 8T2DYqlvf)#RָpUpBŵ;Cs۠?KMƷ:wN@k$NҪ!6IưtK}hSjnA`<:ݖ?Q͎sBFIjAAApm.V۾0*H
 	10	*H
-010	+ 0{*H
-	lj0h*010
-	`He  m휫UBDgZk]H*μX20251007183200Z0	 
-?
-00*?0
+010	+ 0z*H
+	ki0g*010
+	`He  (66"+
+\ȘkxH4Һ20251017142244Z0/k8W
+00@PК
+0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-250915174020Z
-251027174019Z0A10UTimestamp Signer MA110U
+251013173521Z
+251124173520Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
-- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
-^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
+ Jr5aG-ry]JcYjI9J@r<=;5Du>ch$ dnVL׿HTa˨KcnޕTc]fQ15)q۝3Xih",>VqѼdQI̟bJ@	3
+n<{<w
+5B\漗imSraolt9;Rѣˉ ]r*00^P(ɎF 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U"˺?EsD%/n̍N0U0
 	*H
-  'MoRRMre嫕-{O0
-ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
+  o4lq7NƲ|#ӕV_N,4אjOۗcЏ;u|M$ȕ*0$He9QiJ`Z7{˾7u[:1J`J
+6hrco3@Rm#R^ fHV08ڭ9m`ߣWЮ|ψu&wlNW^i``ARc,i]
+arZX`*JxҵiZusV00}LWc0
 	*H
  0b10	UUS10U
 
@@ -191,14 +169,18 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS*?0	+ 0	*H
+Apple Inc.10	UUS@PК
+0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251007183200Z0#	*H
-	1b
-+9|V.P@C0+*H
-	1000`|28bVJ+ێ87䭉0
+251017142244Z0#	*H
+	1~DgyrRjg0+*H
+	1000Oev
+Ecm
+<20
 	*H
-  oaOGIhr5qC(IkolQ$	V2]&iXc9p藗GX\[;/AulDz|hˠb}-DZsb0J<:1μXU/0u^HN)\r#/vJ[7	~\]H&k|%11|	omui>bJI)'Al_ÅyFY%d!      
\ No newline at end of file
+  vg󊗋
+eFa^PYwp,l{xwR=6) 1`|y̈B`Ȧiz%4MCaRc<!1>bz?:d+!Ĩ|rg1~q0[61VV^m|Xh}1C*ǁ7\0^=oǊva
+[AQ~PQaq)Di"K\lv^oEVeTRr`^¿4m%      
\ No newline at end of file
