@@ -1,34 +1,10 @@
-    Mac OS X            	   2  *O     *                                      ATTR      *  L  )5                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      	     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Gjuliac-trim-stdlib A427R7F42H !R3~v1                                        4m蹃CUd                    J_N}qb
-\{ǭZqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac-trim-stdlib                    
+    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-trim-stdlib A427R7F42H 4m蹃CUd                    J_N}qb
+\{ǭZ                            juliac-trim-stdlib                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4                      Gjuliac-trim-stdlib A427R7F42H ONvHl_Zt+5b4UEhY2                                                                9R'
+A427R7F42H                4                      Gjuliac-trim-stdlib A427R7F42H 9R'
 N|4Xaؼ t                                ل#Fm:Oa{w&YѶTc0	*H
 010
 	`He 0	*H
@@ -107,48 +83,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251007183158Z0/	*H
-	1" <:+@gץcЎAʛ0[	*Hcd	1N0+7QDP=d90-	`He y41aֽf0伀c(?wətK0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251017142243Z0/	*H
+	1" ߿vF`HBjA
+/ZE-݂`0[	*Hcd	1N0+)qD`fTzvw0-	`He .\XSKWj'kI]ܲ9Կ-=ӌ;0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		FZjqyjfHExedURvZ9ERQPRlkOd8=
+		tClxkPVEYAtmhbdUod56FXbS9Hc=
 		</data>
 		<data>
-		l3mJiTQb/eoxkmHK5Na9ZjARu+Q=
+		+y5cWNtTS4fZV2rWJ/Wb42sS8kk=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  #>Z?j[*s0#4J~+h<ҕ56'%%SPe)[i)bv
-߸QlǬ8˓Dh/]t]fʇnk	r9hmkAd!K¢HrAq&zQ7J[ X<CM:UjCItտ#p;:*lѺ	0 n,^kJwU+Z0*H
+  wW XR%ā*IL\w?Gu2;x޿	Ъ) L9o̝U1gztt$E<GOֆG\bis`n=*E_^.~E@lgaX~1x<
+4#2uԞ،<
+LEc,ؑyL Wz=;%hQWAc2$l1OB!%Ӑu ٓ0*H
 	10	*H
 010	+ 0z*H
 	ki0g*010
-	`He  ˿(L:8rm|tTr"q(ݽM`20251007183200Z0XHir:
-00*?0
+	`He  Ƴ>XˡyנiZ_ Edp}w20251017142244Z0x
+00@PК
+0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-250915174020Z
-251027174019Z0A10UTimestamp Signer MA110U
+251013173521Z
+251124173520Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
-- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
-^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
+ Jr5aG-ry]JcYjI9J@r<=;5Du>ch$ dnVL׿HTa˨KcnޕTc]fQ15)q۝3Xih",>VqѼdQI̟bJ@	3
+n<{<w
+5B\漗imSraolt9;Rѣˉ ]r*00^P(ɎF 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U"˺?EsD%/n̍N0U0
 	*H
-  'MoRRMre嫕-{O0
-ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
+  o4lq7NƲ|#ӕV_N,4אjOۗcЏ;u|M$ȕ*0$He9QiJ`Z7{˾7u[:1J`J
+6hrco3@Rm#R^ fHV08ڭ9m`ߣWЮ|ψu&wlNW^i``ARc,i]
+arZX`*JxҵiZusV00}LWc0
 	*H
  0b10	UUS10U
 
@@ -189,14 +169,18 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS*?0	+ 0	*H
+Apple Inc.10	UUS@PК
+0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251007183200Z0#	*H
-	17(0B͛mWA+$0+*H
-	1000`|28bVJ+ێ87䭉0
+251017142244Z0#	*H
+	1>OX`k3w=0+*H
+	1000Oev
+Ecm
+<20
 	*H
-  m^6$Ӷ`G
-@p+"j0"wO:_pf$a131Tr8Roud`ڸRTu"1-HkR"i U?Y^;ǉX'@5muSq]Y*`3Pb(Jng&8QU|!U:J4jcD'6|-Xnfcqe|!eV      
\ No newline at end of file
+  
+/1Y%|"1bFZ-vC2܉Է͡ɀVlyA6rȷ#<MU@u絙UKXM qF`XX
+e8[`4F5s{X0nmr[wJABԜ)P7EMٌBӢJ]`RqArlς <m@#Dk=Q5m'ɘ*V~`      
\ No newline at end of file
