@@ -1,34 +1,9 @@
-    Mac OS X            	   2  *+     *]                                      ATTR      *]  L  )                 L     com.apple.cs.CodeDirectory     
-    com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        ,             ;juliac A427R7F42H !R3~v1                                        s?Nǁj$)Z%                    (z3|.MKT\Eqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            juliac                    
+    Mac OS X            	   2  &q     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      J      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              n   4        ,             ;juliac A427R7F42H s?Nǁj$)Z%                    (z3|.MKT\E                            juliac                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H               4        ,              ;juliac A427R7F42H ONvHl_Zt+5b4UEhY2                                                                ;ddkJLq}~@Î 漮`ȴ                                [V5ɬ#F;
+A427R7F42H                4        ,              ;juliac A427R7F42H ;ddkJLq}~@Î 漮`ȴ                                [V5ɬ#F;
 +[<zʐL\0	*H
 010
 	`He 0	*H
@@ -107,50 +82,53 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251007183158Z0/	*H
-	1" 0s ܵlL8j&xf0[	*Hcd	1N0+V]7֪"Gq%祛>k0-	`He V\a*0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251017142243Z0/	*H
+	1"  C͟y\4z"R:$P0[	*Hcd	1N0+u->I<IakK0-	`He {,gGQ(RX)D@0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		Vl031qoiA0dxEiW056WbPmsM8oI=
+		dS0+SQeIPAtJYbWX9/QM8/NrnEs=
 		</data>
 		<data>
-		BsHwVr6TXMYT7pvBpwKUvRj26OM=
+		+LDjrtB7LGdHkZf9UZS5GihS59M=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  Iwmwj$	ETm!^-)@ARb;$Ę𸌢a>Nw3c
-FLGDI3bG9zLIς#Je(A% iz>{D,dܜ[2J@m%1Hg{^B<g?62d&R2JYΥ';JgT
-8v>սL`<mtA"1~*q'j2t0*H
+  dSD\Q"DI]?$Ϸ1/2zRm\&Ys)Ahco^%\XHJ_4gΨf~.Px
+|. ʣHI\Y;Bba4zgm\ewģrf	3 
+O+
+pBO$H<j&>CRxȁG1-!Hp,7 cG"7fq^T'`0*H
 	10	*H
-010	+ 0z*H
-	ki0g*010
-	`He  ru![7fy4p x&4ځ
-20251007183200Z0oL
-001|0
+010	+ 0{*H
+	lj0h*010
+	`He  N`jh2ӝ2+s!7T<+"t20251017142244Z0	 ]08?
+00oz0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-250915173520Z
-251027173519Z0A10UTimestamp Signer MA210U
+251013173520Z
+251124173519Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- HLèX%&IEF~PVjۢ1-EU@M@KnQ_pUƂo ȺHm-ݭq	O*bumBq~NvV- U:k)YlR6p
-gukhʯ)v{eSicN4ζ>]a^Gi}
-$%?V̊ȯgme}RkaPb[ 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0URphe_G:ذ0U0
+ Alv
+]kZF) $
+	vy5*CQNsS;!!f5RUB*,7+BﴚdW;
+6Ƕڀ7dɉx&q{
+aws/(DI-G9@87lgHD"!ͽO#A˳p?U1+.ɶޒM4gm
+nr#P(@Lu 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U|"Pߢ_\Vd0U0
 	*H
-  LeGژ0D?-ἁv?̓4v/&\sID3YnS3;meN#W[Ȫ\
- %3~2xЧT?J/.vS%B}az8 X0.hgͲOeFX򼛂&NAA4IVr!"8?qMl/fk)i_(RbSdu1݇x^s['q6?W>TUL՘~ȼ'00}LWc0
+  #h,&[a'E'Rb4"IPrmoW5ROt(Yr?qKkz%cH[E$mQTgM%fi:c*ũ)!@涪
+R@[YQu:w߲TL>H愀)WrHX76RV[8lmzDɒwN~~֭2twātӀ&N}VV~D00}LWc0
 	*H
  0b10	UUS10U
 
@@ -191,16 +169,16 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS1|0	+ 0	*H
+Apple Inc.10	UUSoz0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251007183200Z0#	*H
-	1?^jIp4RBO0+*H
-	1000j?40z|[&`i0
+251017142244Z0#	*H
+	1]10&MEo|%Ub,0+*H
+	1000-(tWY#ţg	7M0
 	*H
-  Ўx.de9h(	L0|IՋ)n7K&1aF.v5*?:۝ί	\]{mؐfn;e,%̓`O(д,hQ"r@R.6b<D9<Vwy[
-,]6cGlll.YFd
-ʑmx
-o"/U1&󒆡7?_jrfheu tjP.      
\ No newline at end of file
+  "SykM^՝o7@3|_;Y҄Z%9X훣zcXW|ņe)Pbn9"qFY.aTyZwU?"I@)v	\Ԥ3ަ*⃛ą'騥`%?ji{z:$i}%86߬Jm0Q$Rd>H
+ ի*Bq
+[2ٛU
+,s?ƿ)䀣W      
\ No newline at end of file
