@@ -1,34 +1,9 @@
-    Mac OS X            	   2  *5     *g                                      ATTR      *g  L  )                 L     com.apple.cs.CodeDirectory     
-    com.apple.cs.CodeEntitlements            com.apple.cs.CodeRequirements        	   com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     >generator A427R7F42H !R3~v1                                        y*-#q0                    MKxӧ!axqq  <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>com.apple.security.automation.apple-events</key>
-	<true/>
-	<key>com.apple.security.get-task-allow</key>
-	<true/>
-	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
-	<true/>
-	<key>com.apple.security.cs.allow-jit</key>
-	<true/>
-	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
-	<true/>
-	<key>com.apple.security.cs.debugger</key>
-	<true/>
-	<key>com.apple.security.cs.disable-library-validation</key>
-	<true/>
-	<key>com.apple.security.device.audio-input</key>
-	<true/>
-	<key>com.apple.security.device.camera</key>
-	<true/>
-</dict>
-</plist>
-                            	generator                     
+    Mac OS X            	   2  &z     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      Q      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              q   4                     >generator A427R7F42H y*-#q0                    MKxӧ!ax                            	generator                     
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H    	           4                      >generator A427R7F42H ONvHl_Zt+5b4UEhY2                                                                z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
+A427R7F42H                4                      >generator A427R7F42H z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -106,50 +81,53 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251007183158Z0/	*H
-	1" ҫH(iͱVps59t40[	*Hcd	1N0+ℶץw8&ZeXw10-	`He sX@KƒtK3A)Y/Jу0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251017142244Z0/	*H
+	1" ױP~Oףؠ
+0[	*Hcd	1N0+ajO${fQP0-	`He 0 3ݴ<l,#_?_{10[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		8gfihLbXpXcZBTjNJlpl3Fh3AjE=
+		oQvb7WHf7mr4TyR7if64ZlFQj7I=
 		</data>
 		<data>
-		q3Oh8ljg+Q5AS8aS/3RLM58eBEE=
+		MAAzrt20sAY8bCyKGSOS+BdfPwY=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  d
-D࿄h#A^(|Wh36vmK!.jY"coScđ,*	^n:BP]! _#DT^'2o]
-
-q? `GSUYY7O#kFpBBH>m(=ARNKNoqIu$m}-эY2*DȜ@a`':SXR@]嫑N-G*y e[0*H
+  )\/Lͮ> t(lqDW:4f<uؼx&qNHH3O0vm<|):)D!a"I}/Rd'kyVz[8c=0<pTrpIazg_VD驑h lS\>\sg!R1mw(L:+a`]%U
+x^S
+2̫5Ocs>&&UUdlۧ2]^LwШt0*H
 	10	*H
 010	+ 0z*H
 	ki0g*010
-	`He  i6LB:U:qyl7ЭKS+<20251007183158Z0AGX;
-00*?0
+	`He  \qH?aǎ3R|N4>I$P6~0O@20251017142245Z0*5lฏ
+00oz0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-250915174020Z
-251027174019Z0A10UTimestamp Signer MA110U
+251013173520Z
+251124173519Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
-- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
-^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
+ Alv
+]kZF) $
+	vy5*CQNsS;!!f5RUB*,7+BﴚdW;
+6Ƕڀ7dɉx&q{
+aws/(DI-G9@87lgHD"!ͽO#A˳p?U1+.ɶޒM4gm
+nr#P(@Lu 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U|"Pߢ_\Vd0U0
 	*H
-  'MoRRMre嫕-{O0
-ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
+  #h,&[a'E'Rb4"IPrmoW5ROt(Yr?qKkz%cH[E$mQTgM%fi:c*ũ)!@涪
+R@[YQu:w߲TL>H愀)WrHX76RV[8lmzDɒwN~~֭2twātӀ&N}VV~D00}LWc0
 	*H
  0b10	UUS10U
 
@@ -190,17 +168,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS*?0	+ 0	*H
+Apple Inc.10	UUSoz0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251007183158Z0#	*H
-	1sɦ ^bCU0+*H
-	1000`|28bVJ+ێ87䭉0
+251017142245Z0#	*H
+	1h1'* 'o)_0+*H
+	1000-(tWY#ţg	7M0
 	*H
-  3Xp|>
-_Z	q+p6
-XNl*ט*F 5| 7kS`dm;60!$[ JSĂ"IF:v>iʭ '+gEMRR3pV6OKif/
-DЖȠq?>X'趚O=Xf;ś֋Wl}8@iG9uXoy "EڧF,5-
-+|><1|@A3      
\ No newline at end of file
+  TK/>{i DW>u^Z8G}08\=-yUܽa>c<dǫB<ضR-^e]O,VwQ|rm0A?5%GFŦJ棟I/mAq+{ZM
+ Vq+A:f}߲@.YW)Wd	Tt ?uuq\n8ĸ/{R.AE7;,xc/?@ W@=[l      
\ No newline at end of file
